@@ -36,4 +36,11 @@ class SearchSettings():
     """
     searchOrder = 0
     recentSearches = QStringList()
-     
+    
+class VideoSharingSettings():
+    """
+    Provides the setting for sharing videos via social media.
+    """
+    raiseTwitterAuthorisationDialog = True
+    twitterAccessTokenKey = ""
+    twitterAccessTokenSecret = ""
