@@ -115,6 +115,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
         VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
         VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  "18").toPyObject()
+        VideoSharingSettings.raiseTwitterAuthorisationDialog = settings.value("twitterAuthDialog", True).toBool()
+        VideoSharingSettings.twitterAccessTokenKey = settings.value("twitterKey", "").toString()
+        VideoSharingSettings.twitterAccessTokenSecret = settings.value("twitterSecret", "").toString()
         SearchSettings.searchOrder = settings.value("searchOrder",  0).toInt()[0]
         SearchSettings.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
         
@@ -130,6 +133,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
         downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
         downloadFormat = QVariant(VideoDownloadSettings.downloadFormat)
+        twitterAuthDialog = QVariant(VideoSharingSettings.raiseTwitterAuthorisationDialog)
+        twitterKey = QVariant(VideoSharingSettings.twitterAccessTokenKey)
+        twitterSecret = QVariant(VideoSharingSettings.twitterAccessTokenSecret)
         searchOrder = QVariant(SearchSettings.searchOrder)
         recentSearches = QVariant(SearchSettings.recentSearches)
         settings.setValue("userDict", userDict)
@@ -139,6 +145,9 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         settings.setValue("downloadStatus", downloadStatus)
         settings.setValue("playbackFormat", playbackFormat)
         settings.setValue("downloadFormat", downloadFormat)
+        settings.setValue("twitterAuthDialog", twitterAuthDialog)
+        settings.setValue("twitterKey", twitterKey)
+        settings.setValue("twitterSecret", twitterSecret)
         settings.setValue("searchOrder", searchOrder)
         settings.setValue("recentSearches", recentSearches)
 
