@@ -281,8 +281,9 @@ class YouTubeDownloadQueueFeed(QThread):
         """
         Retrieves and returns the video feed.
         """
-        for video in YouTubeVideoDownloader.downloadQueue:
+        for task in YouTubeVideoDownloader.taskQueue:
             try:
+                video = task.video
                 thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
                 videoData = (video, thumbnail)
                 self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), videoData)
@@ -362,7 +363,6 @@ class YouTubeVideoDownloader(object):
     Manages download tasks in the download queue.
     """
     # Static variables
-    downloadQueue = []
     taskQueue = []
     currentTask = None
     currentStatus = "inactive"
@@ -378,7 +378,6 @@ class YouTubeVideoDownloader(object):
         """
         Add the video to the download queue. 
         """
-        YouTubeVideoDownloader.downloadQueue.append(video)
         task = DownloadTask(video)
         YouTubeVideoDownloader.taskQueue.append(task)
         if YouTubeVideoDownloader.currentStatus == "inactive" and VideoDownloadSettings.defaultTaskStatus == "queued":
@@ -411,10 +410,9 @@ class YouTubeVideoDownloader(object):
     @staticmethod
     def clearTasks():
         """
-        Clears the taskQueue and the downloadQueue.
+        Clears the taskQueue.
         """
         YouTubeVideoDownloader.taskQueue = []
-        YouTubeVideoDownloader.downloadQueue = []
     
     @staticmethod
     def run():
